# ckipsvr_python_client
[![Build Status](https://travis-ci.org/i3thuan5/ckipsvr_python_client.svg?branch=master)](https://travis-ci.org/i3thuan5/ckipsvr_python_client)
[![Coverage Status](https://coveralls.io/repos/github/i3thuan5/ckipsvr_python_client/badge.svg?branch=master)](https://coveralls.io/github/i3thuan5/ckipsvr_python_client?branch=master)

ckip斷詞服務的python client